-----------------------------------------------------------------------------------------------
-- Client Lua Script for GTAS_ReadyCheck
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
require "Apollo"
require "GameLib"
require "GroupLib"
require "ChatChannelLib"
 
-----------------------------------------------------------------------------------------------
-- GTAS_ReadyCheck Module Definition
-----------------------------------------------------------------------------------------------
local GTAS_ReadyCheck = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
local kcrSelectedText = ApolloColor.new("UI_BtnTextHoloPressedFlyby")
local kcrNormalText = ApolloColor.new("UI_BtnTextHoloNormal")
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function GTAS_ReadyCheck:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here
	o.tItems = {} -- keep track of all the list items

    return o
end

function GTAS_ReadyCheck:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end

function GTAS_ReadyCheck:OnSave(eLevel)
    if eLevel ~= GameLib.CodeEnumAddonSaveLevel.Account then
        return nil
    end

    -- create a table to hold our data
    local tSave = {}
	
    return tSave
end

function GTAS_ReadyCheck:OnRestore(eLevel, tData)
   -- tSaved = tData
   -- if tSaved.tRC~= nil then
   --   tRC = tSaved.tRC
   -- end
	    
end 

 

-----------------------------------------------------------------------------------------------
-- GTAS_ReadyCheck OnLoad
-----------------------------------------------------------------------------------------------
function GTAS_ReadyCheck:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("GTAS_ReadyCheck.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- GTAS_ReadyCheck OnDocLoaded
-----------------------------------------------------------------------------------------------
function GTAS_ReadyCheck:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "GTAS_ReadyCheckForm", nil, self)
		self.wndReadyCheck = Apollo.LoadForm(self.xmlDoc, "wndReadyCheck", nil, self)
	
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
		-- item list
		self.wndItemList = self.wndMain:FindChild("ItemList")
	    self.wndMain:Show(false, true)
		self.wndReadyCheck:Show(false,true)
		
		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("readychecker", "OnGTAS_ReadyCheckOn", self)
		Apollo.RegisterSlashCommand("rc", 		"OnShowReadyCheckButton",self)
		--Apollo.RegisterSlashCommand("kv",		"OnGroupMemberKeyValues",self)

		Apollo.RegisterTimerHandler("OneSecTimer",	"OnTimer",self)
		--Apollo.RegisterEventHandler("PartyJoined", 	"OnPartyJoined",self)
		self.timer = ApolloTimer.Create(3.0, true, "OnTimer", self)

		-- Do additional Addon initialization here
		ChatSystemLib.PostOnChannel(2,"GTAS:ReadyCheck:  GTAS:ReadyCheck loaded.  Use /rc to activate the button.  Click it to start the ready check.  \nIgnore the party message, as Carbine's default party message for ready check results is wrong.")
	end
end

-----------------------------------------------------------------------------------------------
-- GTAS_ReadyCheck Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

-- on SlashCommand "/readychecker"
function GTAS_ReadyCheck:OnGTAS_ReadyCheckOn()
	self.wndMain:Invoke() -- show the window
	self:OnGroupMemberKeyValues()
end

-- on SlashCommand "/kv"
function GTAS_ReadyCheck:OnGroupMemberKeyValues()
	nGroupMembers = GroupLib.GetMemberCount()
	tPlayerInfo = {}
	tPlayerInfo.PlayerName = {}
	tPlayerInfo.ReadyStatus = {}
	for i = 1, nGroupMembers, 1 do
		tPlayerData = GroupLib.GetGroupMember(i)
		PlayerName = tPlayerData["strCharacterName"]
		PlayerStatus = tPlayerData["bReady"]
		if PlayerStatus== true then
			sprReadyStatus = "Crafting_CoordSprites:sprCoord_Checkmark"
		elseif PlayerStatus== false then
			sprReadyStatus = "CRB_CharacterCreateSprites:sprCharC_ClassFooterIconDisabled"
		end

		table.insert(tPlayerInfo.PlayerName, PlayerName)
		table.insert(tPlayerInfo.ReadyStatus, sprReadyStatus)
	
	end
	self:BuildStatusGrid(tPlayerInfo)

end 
		
function GTAS_ReadyCheck:OnShowReadyCheckButton()
	if self.wndReadyCheck:IsShown() ~= true then
		self.wndReadyCheck:Show(true)
	else
		self.wndReadyCheck:Show(false)	
	end
end


-- on timer
function GTAS_ReadyCheck:OnTimer()
	self:OnGroupMemberKeyValues()
	
	--self:UpdateItem(tPlayerInfo)
end

function GTAS_ReadyCheck:OnPartyJoined(unit)

end

-----------------------------------------------------------------------------------------------
-- GTAS_ReadyCheckForm Functions
-----------------------------------------------------------------------------------------------
-- when the Cancel button is clicked
function GTAS_ReadyCheck:OnCancel()
	self.wndMain:Close() -- hide the window
end


-----------------------------------------------------------------------------------------------
-- ItemList Functions
-----------------------------------------------------------------------------------------------


function GTAS_ReadyCheck:UpdateItem(i)
	tPlayerInfo = i
	self.wndMain:FindChild("PlayerName"):SetText(i.PlayerName)
	self.wndMain:FindChild("ReadyStatus"):SetSprite(i.sprReadyStatus)
end
------------------------------------------------------------------------------
-- wndGrid Functions
------------------------------------------------------------------------------
function GTAS_ReadyCheck:BuildStatusGrid(tStatusData)
  tRC = tStatusData
  local strTextColor = "UI_TextHoloBodyHighlight"
  local wndGrid = self.wndMain:FindChild("wndReadyGrid")
  wndGrid:DeleteAll()
 --[[ if self.wndMain:IsVisible() ~= true then 
    self.wndMain:Show(true)
  end]]--
	wndGrid:Show(true,true)
  for key, value in pairs(tRC.PlayerName) do
    if key ~= nil then
      local iCurrRow = wndGrid:AddRow("")
      wndGrid:SetCellDoc(iCurrRow, 1, "<T Font=\"CRB_InterfaceSmall\" TextColor=\""..strTextColor.."\">".. tRC.PlayerName[iCurrRow] .."</T>")
      wndGrid:SetCellImage(iCurrRow, 2, tRC.ReadyStatus[iCurrRow])
    end
  end
end
---------------------------------------------------------------------------------------------------
-- wndReadyCheck Functions
---------------------------------------------------------------------------------------------------

function GTAS_ReadyCheck:OnSendReadyCheck( wndHandler, wndControl, eMouseButton )
	GroupLib.ReadyCheck()
	self:OnGTAS_ReadyCheckOn()
end

-----------------------------------------------------------------------------------------------
-- GTAS_ReadyCheck Instance
-----------------------------------------------------------------------------------------------
local GTAS_ReadyCheckInst = GTAS_ReadyCheck:new()
GTAS_ReadyCheckInst:Init()
